@@ -22,10 +22,17 @@ our $Debug = 0;
 
 use Rose::Class::MakeMethods::Generic
 (
-  inheritable_scalar => [ 'error', 'total', 'error_mode' ],
+  inheritable_scalar =>
+  [
+    'error',
+    'total', 
+    'error_mode', 
+    'default_objects_per_page',
+  ],
 );
 
 __PACKAGE__->error_mode('fatal');
+__PACKAGE__->default_objects_per_page(20);
 
 sub handle_error
 {
@@ -395,6 +402,30 @@ sub get_objects
     }
   }
 
+  # Handle "page" arguments
+  if(exists $args{'page'} || exists $args{'per_page'})
+  {
+    if(exists $args{'limit'} || exists $args{'offset'})
+    {
+      Carp::croak 'Cannot include the "page" or "per_page" ',
+                  'options when the "limit" or "offset" option ',
+                  'is used';
+    }
+
+    my $page     = delete $args{'page'} || 1;
+    my $per_page = delete $args{'per_page'} || $class->default_objects_per_page;
+
+    $page     = 1  if($page < 1);
+    $per_page = $class->default_objects_per_page  if($per_page < 1);
+
+    $args{'limit'} = $per_page;
+
+    if($page > 1)
+    {
+      $args{'offset'} = ($page - 1) * $per_page;
+    }
+  }
+
   # Pre-process sort_by args
   if(my $sort_by = $args{'sort_by'})
   {
@@ -2063,6 +2094,10 @@ Class methods are provided for fetching objects all at once, one at a time throu
 
 =over 4
 
+=item B<default_objects_per_page [NUM]>
+
+Get or set the default number of items per page, as returned by the L<get_objects|/get_objects> method when used with the C<page> and/or C<per_page> parameters.  The default value is 20.
+
 =item B<delete_objects [PARAMS]>
 
 Delete rows from a table fronted by a L<Rose::DB::Object>-derived class based on PARAMS, where PARAMS are name/value pairs.  Returns the number of rows deleted, or undef if there was an error.
@@ -2235,6 +2270,20 @@ Skip the first NUM rows.  If the database supports some sort of "limit with offs
 
 This parameter can only be used along with the C<limit> parameter, otherwise a fatal error will occur.
 
+=item C<page NUM>
+
+Show page number NUM of objects.  Pages are numbered starting from 1.  A page number less than or equal to zero causes the page number to default to 1.
+
+The number of objects per page can be set by the C<per_page> parameter.  If the C<per_page> parameter is supplied and this parameter is omitted, it defaults to 1 (the first page).
+
+If this parameter is included along with either of the C<limit> or <offset> parameters, a fatal error will occur.
+
+=item C<per_page NUM>
+
+The number of objects per C<page>.   Defaults to the value returned by the L<default_objects_per_page|/default_objects_per_page> class method (20, by default).
+
+If this parameter is included along with either of the C<limit> or <offset> parameters, a fatal error will occur.
+
 =item C<require_objects OBJECTS>
 
 Only fetch rows from the primary table that have all of the associated sub-objects listed in OBJECTS, where OBJECTS is a reference to an array of L<foreign key|Rose::DB::Object::Metadata/foreign_keys> or L<relationship|Rose::DB::Object::Metadata/relationships> names defined for C<object_class>.  The supported relationship types are "L<one to one|Rose::DB::Object::Metadata::Relationship::OneToOne>," "L<one to many|Rose::DB::Object::Metadata::Relationship::OneToMany>," and  "L<many to many|Rose::DB::Object::Metadata::Relationship::ManyToMany>".
