@@ -7,9 +7,9 @@ use Rose::DB::Object::MakeMethods::Date;
 use Rose::DB::Object::Metadata::Column::Date;
 our @ISA = qw(Rose::DB::Object::Metadata::Column::Date);
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
-__PACKAGE__->add_method_maker_argument_names
+__PACKAGE__->add_common_method_maker_argument_names
 (
   qw(time_zone)
 );
@@ -17,13 +17,15 @@ __PACKAGE__->add_method_maker_argument_names
 Rose::Object::MakeMethods::Generic->make_methods
 (
   { preserve_existing => 1 },
-  scalar => [ __PACKAGE__->method_maker_argument_names ]
+  scalar => [ __PACKAGE__->common_method_maker_argument_names ]
 );
 
-sub type { 'datetime' }
+foreach my $type (__PACKAGE__->available_method_types)
+{
+  __PACKAGE__->method_maker_type($type => 'datetime');
+}
 
-sub method_maker_class { 'Rose::DB::Object::MakeMethods::Date' }
-sub method_maker_type  { 'datetime' }
+sub type { 'datetime' }
 
 sub should_inline_value
 {
@@ -61,7 +63,7 @@ Rose::DB::Object::Metadata::Column::Datetime - Datetime column metadata.
   use Rose::DB::Object::Metadata::Column::Datetime;
 
   $col = Rose::DB::Object::Metadata::Column::Datetime->new(...);
-  $col->make_method(...);
+  $col->make_methods(...);
   ...
 
 =head1 DESCRIPTION
@@ -70,17 +72,29 @@ Objects of this class store and manipulate metadata for datetime columns in a da
 
 This class inherits from L<Rose::DB::Object::Metadata::Date>. Inherited methods that are not overridden will not be documented a second time here.  See the L<Rose::DB::Object::Metadata::Date> documentation for more information.
 
-=head1 OBJECT METHODS
+=head1 METHOD MAP
 
 =over 4
 
-=item B<method_maker_class>
+=item C<get_set>
 
-Returns L<Rose::DB::Object::MakeMethods::Date>.
+L<Rose::DB::Object::MakeMethods::Date>, L<datetime|Rose::DB::Object::MakeMethods::Date/datetime>, C<type =E<gt> 'datetime', ...>
 
-=item B<method_maker_type>
+=item C<get>
 
-Returns C<datetime>.
+L<Rose::DB::Object::MakeMethods::Date>, L<datetime|Rose::DB::Object::MakeMethods::Date/datetime>, C<type =E<gt> 'datetime', ...>
+
+=item C<get_set>
+
+L<Rose::DB::Object::MakeMethods::Date>, L<datetime|Rose::DB::Object::MakeMethods::Date/datetime>, C<type =E<gt> 'datetime', ...>
+
+=back
+
+See the L<Rose::DB::Object::Metadata::Column|Rose::DB::Object::Metadata::Column/"MAKING METHODS"> documentation for an explanation of this method map.
+
+=head1 OBJECT METHODS
+
+=over 4
 
 =item B<parse_value DB, VALUE>
 
